file_picker_desktop library

Enums

FileType

Functions

getDirectoryPath({String dialogTitle = 'Please select a directory:'}) Future<String?>
Opens a dialog to let the user select a directory and returns its absolute path.
pickFiles({String dialogTitle = 'Please select file(s):', FileType type = FileType.any, List<String>? allowedExtensions, bool allowMultiple = false, bool withData = false, bool withReadStream = false}) Future<FilePickerResult?>
Opens a dialog to let the user select one or multiple files and retrieves the file(s) from the underlying platform.
saveFile({String dialogTitle = 'Please select the file destination:', FileType type = FileType.any, List<String>? allowedExtensions, String? defaultFileName}) Future<String?>
Opens a save file dialog which lets the user select a location and a file name to save a file.